#!/usr/bin/env python

# sugar-lint: disable

import os
import sys
import threading
from os.path import exists

sys.path.insert(0, '..')
from __init__ import Test, main

from sugar_mothership import env, util, import_leases


class ImportTest(Test):

    def test_import_lease_Lines(self):
        lease_text = \
                'act01: SHF706002A7 K 00110529T135103Z sig01: sha256\n' \
                'act01: SHF706002A8 K 00110529T135103Z sig01: sha256\n'
        self.touch(('import', lease_text))
        assert not exists('leases/A7/SHF706002A7')
        assert not exists('leases/A8/SHF706002A8')
        import_leases.import_leases(['import'])
        assert exists('leases/A7/SHF706002A7')
        assert exists('leases/A8/SHF706002A8')
        self.assertEqual(lease_text.split('\n')[0] + '\n', file('leases/A7/SHF706002A7').read())
        self.assertEqual(lease_text.split('\n')[1] + '\n', file('leases/A8/SHF706002A8').read())

    def test_import_lease_Json(self):
        leases = [1, {'SHF706002A7': 'act01: SHF706002A7 K 00110529T135103Z sig01: sha256\n',
                      'SHF706002A8': 'act01: SHF706002A8 K 00110529T135103Z sig01: sha256\n',
                      }]
        self.touch(('import', util.json.dumps(leases)))
        assert not exists('leases/A7/SHF706002A7')
        assert not exists('leases/A8/SHF706002A8')
        import_leases.import_leases(['import'])
        assert exists('leases/A7/SHF706002A7')
        assert exists('leases/A8/SHF706002A8')
        self.assertEqual(leases[1]['SHF706002A7'], file('leases/A7/SHF706002A7').read())
        self.assertEqual(leases[1]['SHF706002A8'], file('leases/A8/SHF706002A8').read())

    def test_import_lease_delegation(self):
        delegation_text = \
                'del01: SHF706002A1 00000000000000000000000000000001 sig02: sha256\n' \
                'del01: SHF706002A2 00000000000000000000000000000002 sig02: sha256\n'
        self.touch(('import', delegation_text))
        assert not exists('lease-delegations/A1/SHF706002A1')
        assert not exists('lease-delegations/A2/SHF706002A2')
        import_leases.import_lease_delegations(['import'])
        assert exists('lease-delegations/A1/SHF706002A1')
        assert exists('lease-delegations/A2/SHF706002A2')
        self.assertEqual(delegation_text.split('\n')[0] + '\n', file('lease-delegations/A1/SHF706002A1').read())
        self.assertEqual(delegation_text.split('\n')[1] + '\n', file('lease-delegations/A2/SHF706002A2').read())

    def test_import_oats_delegation(self):
        delegation_text = \
                'del01: SHF706002A1 00000000000000000000000000000001 sig02: sha256\n' \
                'del01: SHF706002A2 00000000000000000000000000000002 sig02: sha256\n'
        self.touch(('import', delegation_text))
        assert not exists('oats-delegations/A1/SHF706002A1')
        assert not exists('oats-delegations/A2/SHF706002A2')
        import_leases.import_oats_delegations(['import'])
        assert exists('oats-delegations/A1/SHF706002A1')
        assert exists('oats-delegations/A2/SHF706002A2')
        self.assertEqual(delegation_text.split('\n')[0] + '\n', file('oats-delegations/A1/SHF706002A1').read())
        self.assertEqual(delegation_text.split('\n')[1] + '\n', file('oats-delegations/A2/SHF706002A2').read())

    def test_import_dir(self):
        lease_1 = 'act01: SHF706002A7 K 00110529T135103Z sig01: sha256'
        self.touch(('import/lease.sig', lease_1))

        lease_2 = 'act01: SHF706002A8 K 00110529T135103Z sig01: sha256'
        self.touch(('import/leases.dat', lease_2))

        lease_delegation = 'del01: SHF706002A1 00000000000000000000000000000001 sig02: sha256'
        self.touch(('import/d-lease.sig', lease_delegation))

        oats_delegations = 'del01: SHF706002A2 00000000000000000000000000000002 sig02: sha256'
        self.touch(('import/d-oats.sig', oats_delegations))

        import_leases.import_dir(['import'])

        assert exists('leases/A7/SHF706002A7')
        self.assertEqual(lease_1 + '\n', file('leases/A7/SHF706002A7').read())

        assert exists('leases/A8/SHF706002A8')
        self.assertEqual(lease_2 + '\n', file('leases/A8/SHF706002A8').read())

        assert exists('lease-delegations/A1/SHF706002A1')
        self.assertEqual(lease_delegation + '\n', file('lease-delegations/A1/SHF706002A1').read())

        assert exists('oats-delegations/A2/SHF706002A2')
        self.assertEqual(oats_delegations + '\n', file('oats-delegations/A2/SHF706002A2').read())


if __name__ == '__main__':
    main()
